package cn.iocoder.yudao.module.order.service.order;

import java.util.*;
import javax.validation.*;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.module.order.dal.dataobject.order.OrderDO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderMutual.OrderMutualDO;
import cn.iocoder.yudao.module.order.vo.order.OrderBackVO;
import cn.iocoder.yudao.module.order.vo.orderGuanlian.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderGuanlian.OrderGuanlianDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 订单关联 Service 接口
 *
 * @author 系统管理员
 */
public interface OrderGuanlianService extends IService<OrderGuanlianDO> {

    /**
     * 创建订单关联
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createGuanlian(@Valid OrderGuanlianCreateReqVO createReqVO);

    /**
     * 更新订单关联
     *
     * @param updateReqVO 更新信息
     */
    void updateGuanlian(@Valid OrderGuanlianUpdateReqVO updateReqVO);

    /**
     * 删除订单关联
     *
     * @param id 编号
     */
    void deleteGuanlian(Long id);

    /**
     * 根据订单id删除订单关联
     * @param orderId 原订单id
     * @param splitOrderIds 拆单后的所有订单id
     * @param type 拆单传1  撤销拆单传2
     */
    void dealGuanlianByOrderId(Long orderId,List<Long> splitOrderIds,int type);

    /**
     * 获得订单关联
     *
     * @param id 编号
     * @return 订单关联
     */
    OrderGuanlianDO getGuanlian(Long id);

    /**
     * 获得订单关联列表
     *
     * @param ids 编号
     * @return 订单关联列表
     */
    List<OrderGuanlianDO> getGuanlianList(Collection<Long> ids);

    /**
     * 获得订单关联分页
     *
     * @param page  分页查询
     * @param query 查询
     * @return 订单关联分页
     */
    PageResult<OrderGuanlianDO> getGuanlianPage(OrderGuanlianQueryVO query, PageVO page);

    /**
     * 获得订单关联列表, 用于 Excel 导出
     *
     * @param query 查询
     * @return 订单关联列表
     */
    List<OrderGuanlianDO> getGuanlianList(OrderGuanlianQueryVO query);

    void batchCreateGuanlian(List<OrderGuanlianCreateReqVO> createReqVOList);

    PageResult<OrderGuanlianBackVO> getGuanlianOrderByOrderId(OrderGuanlianQueryVO orderGuanlianQueryVO, PageParam pageParam);

    PageResult<OrderBackVO> getUnGuanlianOrderByOrderId(OrderGuanlianQueryVO orderGuanlianQueryVO, PageVO pageVO);

    void deleteGuanlianOrderByOrderId(OrderGuanlianQueryVO orderGuanlianQueryVO);

    void deleteBatchGuanlianOrderByOrderId(List<OrderGuanlianQueryVO> orderGuanlianQueryVOList);

    List<OrderGuanlianDO> getGuanlianList(List<Long> orderIdList);

    List<OrderGuanlianDO> getGuanlianListByOrderId(Long orderId);

    List<OrderDO> getRelateOrderListByOrderId(Long orderId);

    OrderTree getAllRelateOrderList(Long orderId, String orderNo);

    List<OrderGuanlianDO> getRelationList(Long orderId);

    OrderTree getAllRelateOrderList(String orderParentNo, List<OrderGuanlianDO> guanlianList);

    /**
     * @param relateOrderId 关联订单ID
     * @param orderDOList   上级订单列表
     */
    void getGuanlianOrderByRelateOrderId(Long relateOrderId, List<OrderDO> orderDOList);

    List<OrderDO> guanlianOrderList(List<String> orderNumbers);

    /**
     * 根据传入订单id删除订单的关联关系 包括主动关联和被动关联
     * @param orderId 订单ID
     */
    void deleteRelationByOrderId(Long orderId);
}
